Crate nosapi_blackbox

Crate nosapi_blackbox 

A library for working with Gameforge’s blackbox string.

See the Blackbox documentation page for examples.

Re-exports

pub use blackbox::Blackbox;
pub use fingerprint::Fingerprint;
pub use vector::VectorString;

Modules

blackbox
Implementation of the blackbox string.
fingerprint
Implementation of the fingerprint struct found in the blackbox string.
vector
Implementation of the vector string used to identity the modification time of the blackbox string.